==> kipi-plugins-trinity_3.5.13.2.orig.tar.xz: kipi-plugins-trinity-3.5.13.2/kipi-plugins/flickrexport/flickrwidget.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2005-07-07
 * Description : a kipi plugin to export images to Flickr web service
 *
 * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
 * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef FLICKRWIDGET_H
#define FLICKRWIDGET_H

// TQt includes.

#include <tqwidget.h>

class TQPushButton;
class TQSpinBox;
class TQCheckBox;
class TQRadioButton;

class KTabWidget;
class KLineEdit;
class KHTMLPart;

namespace KIPI
{
    class Interface;
}

namespace KIPIFlickrExportPlugin
{

class ImagesList;

class FlickrWidget : public TQWidget
{
    Q_OBJECT
  TQ_OBJECT

public:

    enum SettingsTab
    {
        FILELIST=0,
        UPLOAD
    };

public:

    FlickrWidget(TQWidget* parent, KIPI::Interface *iface);
    ~FlickrWidget();

private slots:

    void slotResizeChecked();
    void slotExportHostTagsChecked();

private:

//  TQPushButton*  m_newAlbumBtn;
    TQPushButton*  m_changeUserButton;

    TQCheckBox*    m_resizeCheckBox;
    TQCheckBox*    m_familyCheckBox;
    TQCheckBox*    m_friendsCheckBox;
    TQCheckBox*    m_publicCheckBox;
    TQCheckBox*    m_exportHostTagsCheckBox;
    TQCheckBox*    m_stripSpaceTagsCheckBox;

    TQSpinBox*     m_dimensionSpinBox;
    TQSpinBox*     m_imageQualitySpinBox;

    TQLabel*       m_userNameDisplayLabel;

    KLineEdit*    m_tagsLineEdit;

    KTabWidget*   m_tab;

    KHTMLPart*    m_photoView;

    ImagesList*   m_imglst;

    friend class FlickrWindow;
};

} // namespace KIPIFlickrExportPlugin

#endif // FLICKRWIDGET_H

==> kipi-plugins-trinity-14.1.0.tar.xz: kipi-plugins-trinity-14.1.0/kipi-plugins/flickrexport/flickrwidget.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2005-07-07
 * Description : a kipi plugin to export images to Flickr web service
 *
 * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
 * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef FLICKRWIDGET_H
#define FLICKRWIDGET_H

// TQt includes.

#include <tqwidget.h>

class TQPushButton;
class TQSpinBox;
class TQCheckBox;
class TQRadioButton;

class KTabWidget;
class KLineEdit;
class TDEHTMLPart;

namespace KIPI
{
    class Interface;
}

namespace KIPIFlickrExportPlugin
{

class ImagesList;

class FlickrWidget : public TQWidget
{
    Q_OBJECT
  

public:

    enum SettingsTab
    {
        FILELIST=0,
        UPLOAD
    };

public:

    FlickrWidget(TQWidget* parent, KIPI::Interface *iface);
    ~FlickrWidget();

private slots:

    void slotResizeChecked();
    void slotExportHostTagsChecked();

private:

//  TQPushButton*  m_newAlbumBtn;
    TQPushButton*  m_changeUserButton;

    TQCheckBox*    m_resizeCheckBox;
    TQCheckBox*    m_familyCheckBox;
    TQCheckBox*    m_friendsCheckBox;
    TQCheckBox*    m_publicCheckBox;
    TQCheckBox*    m_exportHostTagsCheckBox;
    TQCheckBox*    m_stripSpaceTagsCheckBox;

    TQSpinBox*     m_dimensionSpinBox;
    TQSpinBox*     m_imageQualitySpinBox;

    TQLabel*       m_userNameDisplayLabel;

    KLineEdit*    m_tagsLineEdit;

    KTabWidget*   m_tab;

    TDEHTMLPart*    m_photoView;

    ImagesList*   m_imglst;

    friend class FlickrWindow;
};

} // namespace KIPIFlickrExportPlugin

#endif // FLICKRWIDGET_H
